==> org.eclipse.incquery.tooling.core.source_0.7.0.201306182109.jar: org/eclipse/incquery/tooling/core/generator/jvmmodel/PatternMatchProcessorClassInferrer.java <==
package org.eclipse.incquery.tooling.core.generator.jvmmodel;

import com.google.inject.Inject;
import org.eclipse.emf.common.util.EList;
import org.eclipse.incquery.patternlanguage.patternLanguage.Pattern;
import org.eclipse.incquery.patternlanguage.patternLanguage.Variable;
import org.eclipse.incquery.runtime.api.IMatchProcessor;
import org.eclipse.incquery.tooling.core.generator.jvmmodel.JavadocInferrer;
import org.eclipse.incquery.tooling.core.generator.util.EMFJvmTypesBuilder;
import org.eclipse.incquery.tooling.core.generator.util.EMFPatternLanguageJvmModelInferrerUtil;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.common.types.JvmAnnotationReference;
import org.eclipse.xtext.common.types.JvmDeclaredType;
import org.eclipse.xtext.common.types.JvmFormalParameter;
import org.eclipse.xtext.common.types.JvmGenericType;
import org.eclipse.xtext.common.types.JvmMember;
import org.eclipse.xtext.common.types.JvmOperation;
import org.eclipse.xtext.common.types.JvmTypeReference;
import org.eclipse.xtext.xbase.compiler.output.ITreeAppendable;
import org.eclipse.xtext.xbase.lib.Procedures.Procedure1;

/**
 * {@link IMatchProcessor} implementation inferer.
 * 
 * @author Mark Czotter
 */
@SuppressWarnings("all")
public class PatternMatchProcessorClassInferrer {
  @Inject
  private EMFJvmTypesBuilder _eMFJvmTypesBuilder;
  
  @Inject
  private EMFPatternLanguageJvmModelInferrerUtil _eMFPatternLanguageJvmModelInferrerUtil;
  
  @Inject
  private JavadocInferrer _javadocInferrer;
  
  /**
   * Infers the {@link IMatchProcessor} implementation class from a {@link Pattern}.
   */
  public JvmDeclaredType inferProcessorClass(final Pattern pattern, final boolean isPrelinkingPhase, final String processorPackageName, final JvmTypeReference matchClassRef) {
    String _processorClassName = this._eMFPatternLanguageJvmModelInferrerUtil.processorClassName(pattern);
    final Procedure1<JvmGenericType> _function = new Procedure1<JvmGenericType>() {
        public void apply(final JvmGenericType it) {
          it.setPackageName(processorPackageName);
          CharSequence _javadocProcessorClass = PatternMatchProcessorClassInferrer.this._javadocInferrer.javadocProcessorClass(pattern);
          String _string = _javadocProcessorClass.toString();
          PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.setDocumentation(it, _string);
          it.setAbstract(true);
          EList<JvmTypeReference> _superTypes = it.getSuperTypes();
          JvmTypeReference _cloneWithProxies = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.cloneWithProxies(matchClassRef);
          JvmTypeReference _newTypeRef = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.newTypeRef(pattern, IMatchProcessor.class, _cloneWithProxies);
          PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.<JvmTypeReference>operator_add(_superTypes, _newTypeRef);
        }
      };
    final JvmGenericType processorClass = this._eMFJvmTypesBuilder.toClass(pattern, _processorClassName, _function);
    this.inferProcessorClassMethods(processorClass, pattern, matchClassRef);
    return processorClass;
  }
  
  /**
   * Infers methods for Processor class based on the input 'pattern'.
   */
  public boolean inferProcessorClassMethods(final JvmDeclaredType processorClass, final Pattern pattern, final JvmTypeReference matchClassRef) {
    boolean _xblockexpression = false;
    {
      EList<JvmMember> _members = processorClass.getMembers();
      final Procedure1<JvmOperation> _function = new Procedure1<JvmOperation>() {
          public void apply(final JvmOperation it) {
            CharSequence _javadocProcessMethod = PatternMatchProcessorClassInferrer.this._javadocInferrer.javadocProcessMethod(pattern);
            String _string = _javadocProcessMethod.toString();
            PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.setDocumentation(it, _string);
            it.setAbstract(true);
            EList<Variable> _parameters = pattern.getParameters();
            for (final Variable parameter : _parameters) {
              EList<JvmFormalParameter> _parameters_1 = it.getParameters();
              String _parameterName = PatternMatchProcessorClassInferrer.this._eMFPatternLanguageJvmModelInferrerUtil.parameterName(parameter);
              JvmTypeReference _calculateType = PatternMatchProcessorClassInferrer.this._eMFPatternLanguageJvmModelInferrerUtil.calculateType(parameter);
              JvmFormalParameter _parameter = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.toParameter(parameter, _parameterName, _calculateType);
              PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.<JvmFormalParameter>operator_add(_parameters_1, _parameter);
            }
          }
        };
      JvmOperation _method = this._eMFJvmTypesBuilder.toMethod(pattern, "process", null, _function);
      this._eMFJvmTypesBuilder.<JvmOperation>operator_add(_members, _method);
      EList<JvmMember> _members_1 = processorClass.getMembers();
      final Procedure1<JvmOperation> _function_1 = new Procedure1<JvmOperation>() {
          public void apply(final JvmOperation it) {
            EList<JvmAnnotationReference> _annotations = it.getAnnotations();
            JvmAnnotationReference _annotation = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.toAnnotation(pattern, Override.class);
            PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.<JvmAnnotationReference>operator_add(_annotations, _annotation);
            EList<JvmFormalParameter> _parameters = it.getParameters();
            JvmTypeReference _cloneWithProxies = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.cloneWithProxies(matchClassRef);
            JvmFormalParameter _parameter = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.toParameter(pattern, "match", _cloneWithProxies);
            PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.<JvmFormalParameter>operator_add(_parameters, _parameter);
            final Procedure1<ITreeAppendable> _function = new Procedure1<ITreeAppendable>() {
                public void apply(final ITreeAppendable it) {
                  StringConcatenation _builder = new StringConcatenation();
                  _builder.append("process(");
                  {
                    EList<Variable> _parameters = pattern.getParameters();
                    boolean _hasElements = false;
                    for(final Variable p : _parameters) {
                      if (!_hasElements) {
                        _hasElements = true;
                      } else {
                        _builder.appendImmediate(", ", "");
                      }
                      _builder.append("match.");
                      String _terMethodName = PatternMatchProcessorClassInferrer.this._eMFPatternLanguageJvmModelInferrerUtil.getterMethodName(p);
                      _builder.append(_terMethodName, "");
                      _builder.append("()");
                    }
                  }
                  _builder.append(");  \t\t\t\t");
                  _builder.newLineIfNotEmpty();
                  it.append(_builder);
                }
              };
            PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.setBody(it, _function);
          }
        };
      JvmOperation _method_1 = this._eMFJvmTypesBuilder.toMethod(pattern, "process", null, _function_1);
      boolean _add = this._eMFJvmTypesBuilder.<JvmOperation>operator_add(_members_1, _method_1);
      _xblockexpression = (_add);
    }
    return _xblockexpression;
  }
}

==> org.eclipse.incquery.tooling.core.source_0.7.0.201306302207.jar: org/eclipse/incquery/tooling/core/generator/jvmmodel/PatternMatchProcessorClassInferrer.java <==
/**
 * Copyright (c) 2010-2012, Mark Czotter, Istvan Rath and Daniel Varro
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *   Mark Czotter - initial API and implementation
 */
package org.eclipse.incquery.tooling.core.generator.jvmmodel;

import com.google.inject.Inject;
import org.eclipse.emf.common.util.EList;
import org.eclipse.incquery.patternlanguage.patternLanguage.Pattern;
import org.eclipse.incquery.patternlanguage.patternLanguage.Variable;
import org.eclipse.incquery.runtime.api.IMatchProcessor;
import org.eclipse.incquery.tooling.core.generator.jvmmodel.JavadocInferrer;
import org.eclipse.incquery.tooling.core.generator.util.EMFJvmTypesBuilder;
import org.eclipse.incquery.tooling.core.generator.util.EMFPatternLanguageJvmModelInferrerUtil;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.common.types.JvmAnnotationReference;
import org.eclipse.xtext.common.types.JvmDeclaredType;
import org.eclipse.xtext.common.types.JvmFormalParameter;
import org.eclipse.xtext.common.types.JvmGenericType;
import org.eclipse.xtext.common.types.JvmMember;
import org.eclipse.xtext.common.types.JvmOperation;
import org.eclipse.xtext.common.types.JvmTypeReference;
import org.eclipse.xtext.xbase.compiler.output.ITreeAppendable;
import org.eclipse.xtext.xbase.lib.Extension;
import org.eclipse.xtext.xbase.lib.Procedures.Procedure1;

/**
 * {@link IMatchProcessor} implementation inferer.
 * 
 * @author Mark Czotter
 */
@SuppressWarnings("all")
public class PatternMatchProcessorClassInferrer {
  @Inject
  @Extension
  private EMFJvmTypesBuilder _eMFJvmTypesBuilder;
  
  @Inject
  @Extension
  private EMFPatternLanguageJvmModelInferrerUtil _eMFPatternLanguageJvmModelInferrerUtil;
  
  @Inject
  @Extension
  private JavadocInferrer _javadocInferrer;
  
  /**
   * Infers the {@link IMatchProcessor} implementation class from a {@link Pattern}.
   */
  public JvmDeclaredType inferProcessorClass(final Pattern pattern, final boolean isPrelinkingPhase, final String processorPackageName, final JvmTypeReference matchClassRef) {
    String _processorClassName = this._eMFPatternLanguageJvmModelInferrerUtil.processorClassName(pattern);
    final Procedure1<JvmGenericType> _function = new Procedure1<JvmGenericType>() {
        public void apply(final JvmGenericType it) {
          it.setPackageName(processorPackageName);
          CharSequence _javadocProcessorClass = PatternMatchProcessorClassInferrer.this._javadocInferrer.javadocProcessorClass(pattern);
          String _string = _javadocProcessorClass.toString();
          PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.setDocumentation(it, _string);
          it.setAbstract(true);
          EList<JvmTypeReference> _superTypes = it.getSuperTypes();
          JvmTypeReference _cloneWithProxies = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.cloneWithProxies(matchClassRef);
          JvmTypeReference _newTypeRef = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.newTypeRef(pattern, IMatchProcessor.class, _cloneWithProxies);
          PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.<JvmTypeReference>operator_add(_superTypes, _newTypeRef);
        }
      };
    final JvmGenericType processorClass = this._eMFJvmTypesBuilder.toClass(pattern, _processorClassName, _function);
    this.inferProcessorClassMethods(processorClass, pattern, matchClassRef);
    return processorClass;
  }
  
  /**
   * Infers methods for Processor class based on the input 'pattern'.
   */
  public boolean inferProcessorClassMethods(final JvmDeclaredType processorClass, final Pattern pattern, final JvmTypeReference matchClassRef) {
    boolean _xblockexpression = false;
    {
      EList<JvmMember> _members = processorClass.getMembers();
      final Procedure1<JvmOperation> _function = new Procedure1<JvmOperation>() {
          public void apply(final JvmOperation it) {
            JvmTypeReference _newTypeRef = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.newTypeRef(pattern, Void.TYPE);
            it.setReturnType(_newTypeRef);
            CharSequence _javadocProcessMethod = PatternMatchProcessorClassInferrer.this._javadocInferrer.javadocProcessMethod(pattern);
            String _string = _javadocProcessMethod.toString();
            PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.setDocumentation(it, _string);
            it.setAbstract(true);
            EList<Variable> _parameters = pattern.getParameters();
            for (final Variable parameter : _parameters) {
              EList<JvmFormalParameter> _parameters_1 = it.getParameters();
              String _parameterName = PatternMatchProcessorClassInferrer.this._eMFPatternLanguageJvmModelInferrerUtil.parameterName(parameter);
              JvmTypeReference _calculateType = PatternMatchProcessorClassInferrer.this._eMFPatternLanguageJvmModelInferrerUtil.calculateType(parameter);
              JvmFormalParameter _parameter = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.toParameter(parameter, _parameterName, _calculateType);
              PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.<JvmFormalParameter>operator_add(_parameters_1, _parameter);
            }
          }
        };
      JvmOperation _method = this._eMFJvmTypesBuilder.toMethod(pattern, "process", null, _function);
      this._eMFJvmTypesBuilder.<JvmOperation>operator_add(_members, _method);
      EList<JvmMember> _members_1 = processorClass.getMembers();
      final Procedure1<JvmOperation> _function_1 = new Procedure1<JvmOperation>() {
          public void apply(final JvmOperation it) {
            JvmTypeReference _newTypeRef = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.newTypeRef(pattern, Void.TYPE);
            it.setReturnType(_newTypeRef);
            EList<JvmAnnotationReference> _annotations = it.getAnnotations();
            JvmAnnotationReference _annotation = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.toAnnotation(pattern, Override.class);
            PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.<JvmAnnotationReference>operator_add(_annotations, _annotation);
            EList<JvmFormalParameter> _parameters = it.getParameters();
            JvmTypeReference _cloneWithProxies = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.cloneWithProxies(matchClassRef);
            JvmFormalParameter _parameter = PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.toParameter(pattern, "match", _cloneWithProxies);
            PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.<JvmFormalParameter>operator_add(_parameters, _parameter);
            final Procedure1<ITreeAppendable> _function = new Procedure1<ITreeAppendable>() {
                public void apply(final ITreeAppendable it) {
                  StringConcatenation _builder = new StringConcatenation();
                  _builder.append("process(");
                  {
                    EList<Variable> _parameters = pattern.getParameters();
                    boolean _hasElements = false;
                    for(final Variable p : _parameters) {
                      if (!_hasElements) {
                        _hasElements = true;
                      } else {
                        _builder.appendImmediate(", ", "");
                      }
                      _builder.append("match.");
                      String _terMethodName = PatternMatchProcessorClassInferrer.this._eMFPatternLanguageJvmModelInferrerUtil.getterMethodName(p);
                      _builder.append(_terMethodName, "");
                      _builder.append("()");
                    }
                  }
                  _builder.append(");");
                  _builder.newLineIfNotEmpty();
                  it.append(_builder);
                }
              };
            PatternMatchProcessorClassInferrer.this._eMFJvmTypesBuilder.setBody(it, _function);
          }
        };
      JvmOperation _method_1 = this._eMFJvmTypesBuilder.toMethod(pattern, "process", null, _function_1);
      boolean _add = this._eMFJvmTypesBuilder.<JvmOperation>operator_add(_members_1, _method_1);
      _xblockexpression = (_add);
    }
    return _xblockexpression;
  }
}
